@@ -1,26 +1,15 @@
-#    WebService::Pixabay - A Perl 5 interface to Pixabay API.
-#    Copyright (C) 2017  faraco
+#This software is Copyright (c) 2017-2018 by faraco.
 #
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
+#This is free software, licensed under:
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#  The MIT (X11) License
 
 package WebService::Pixabay;
-$WebService::Pixabay::VERSION = '2.2.1';
+$WebService::Pixabay::VERSION = '2.2.2';
 # ABSTRACT: Perl 5 interface to Pixabay API.
 
 use strict;
 use warnings;
-use feature 'say';
 
 use Moo;
 use Function::Parameters;
@@ -103,13 +92,13 @@ WebService::Pixabay - Perl 5 interface to Pixabay API.
 
 =head1 VERSION
 
-version 2.2.1
+version 2.2.2
 
 =head1 SYNOPSIS
 
     use strict;
     use warnings;
-    use v5.10;
+    use feature qw(say);
 
     use WebService::Pixabay;
     use Data::Dumper 'Dumper';
@@ -332,20 +321,15 @@ Returns: Video search metadata.
 
 =back
 
-=begin html
-
-
-
-
-=end html
-
-<a href="https://kritika.io/users/faraco/repos/3011578832649479/heads/master">
-<img src="https://kritika.io/users/faraco/repos/3011578832649479/heads/master/status.svg"/>
+=for html <p>
+<a href="https://kritika.io/users/faraco/repos/3011578832649479/heads/master/">
+<img src="https://kritika.io/users/faraco/repos/3011578832649479/heads/master/status.svg" />
 </a>
+</p>
 
 =head1 SEE ALSO
 
-L<Pixabay API documentations|https://pixabay.com/api/docs>
+L<Pixabay API documentation|https://pixabay.com/api/docs>
 
 L<Moo>
 
@@ -357,8 +341,6 @@ L<WebService::Client>
 
 L<LWP::Online>
 
-L<Data::Printer>
-
 =head1 AUTHOR
 
 faraco <skelic3@gmail.com>
